import { defineBoot } from '#q-app/wrappers'
import { createI18n } from 'vue-i18n'

import messages from 'src/i18n'

export type MessageLanguages = keyof typeof messages
// Type-define 'en-US' as the master schema for the resource
export type MessageSchema = (typeof messages)['en-US']

// See https://vue-i18n.intlify.dev/guide/advanced/typescript.html#global-resource-schema-type-definition
/* eslint-disable @typescript-eslint/no-empty-object-type */
declare module 'vue-i18n' {
  // define the locale messages schema
  export interface DefineLocaleMessage extends MessageSchema {}

  // define the datetime format schema
  export interface DefineDateTimeFormat {}

  // define the number format schema
  export interface DefineNumberFormat {}
}
/* eslint-enable @typescript-eslint/no-empty-object-type */

import { useSettingStore } from 'src/stores/setting' // 导入 setting-store

export default defineBoot(({ app }) => {
  const settingStore = useSettingStore() // 初始化 setting-store
  const i18n = createI18n<{ message: MessageSchema }, MessageLanguages>({
    locale: settingStore.language, // 使用 setting-store 中的语言设置
    legacy: false,
    messages,
  })

  // Set i18n instance on app
  app.use(i18n)
})
